@@ -1,32 +1,19 @@
 /*
-  Copyright (C) 2006-2007 KovoKs <info@kovoks.nl>
+  SPDX-FileCopyrightText: 2006-2007 KovoKs <info@kovoks.nl>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILTRANSPORT_SOCKET_H
-#define MAILTRANSPORT_SOCKET_H
+#pragma once
 
-#include <mailtransport_export.h>
+#include "mailtransport_export.h"
 
-#include <QtNetwork/QSslSocket>
+#include <QSslSocket>
+
+#include <memory>
 
 namespace MailTransport
 {
-
 class SocketPrivate;
 
 /**
@@ -40,9 +27,8 @@ class Socket : public QObject
     Q_OBJECT
 
 public:
-
     /**
-     * Contructor, it will not auto connect. Call reconnect() to connect to
+     * Constructor, it will not auto connect. Call reconnect() to connect to
      * the parameters given.
      * @param parent the parent
      */
@@ -51,7 +37,7 @@ public:
     /**
      * Destructor
      */
-    ~Socket();
+    ~Socket() override;
 
     /**
      * Existing connection will be closed and a new connection will be
@@ -102,11 +88,11 @@ public:
 
 private:
     Q_DECLARE_PRIVATE(Socket)
-    SocketPrivate *const d;
+    std::unique_ptr<SocketPrivate> const d;
 
     Q_PRIVATE_SLOT(d, void slotConnected())
     Q_PRIVATE_SLOT(d, void slotStateChanged(QAbstractSocket::SocketState state))
-    Q_PRIVATE_SLOT(d, void slotModeChanged(QSslSocket::SslMode  state))
+    Q_PRIVATE_SLOT(d, void slotModeChanged(QSslSocket::SslMode state))
     Q_PRIVATE_SLOT(d, void slotSocketRead())
     Q_PRIVATE_SLOT(d, void slotSslErrors(const QList<QSslError> &errors))
 
@@ -131,8 +117,4 @@ Q_SIGNALS:
      */
     void tlsDone();
 };
-
 } // namespace MailTransport
-
-#endif // MAILTRANSPORT_SOCKET_H
-
