@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -15,6 +15,7 @@
 namespace MailTransport
 {
 class TransportManagementWidgetNgPrivate;
+class TransportActivitiesAbstract;
 
 /**
   A widget to manage mail transports.
@@ -35,6 +36,11 @@ public:
     */
     ~TransportManagementWidgetNg() override;
 
+    [[nodiscard]] bool enablePlasmaActivities() const;
+    void setEnablePlasmaActivities(bool newEnablePlasmaActivities);
+
+    void setTransportActivitiesAbstract(TransportActivitiesAbstract *activitiesAbstract);
+
 private:
     std::unique_ptr<TransportManagementWidgetNgPrivate> const d;
 };
